==> qmmp_0.8.2.orig.tar.bz2: qmmp-0.8.2/src/plugins/Input/mpc/translations/mpc_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>DecoderMPCFactory</name>
    <message>
        <location filename="../decodermpcfactory.cpp" line="62"/>
        <source>Musepack Plugin</source>
        <translation>Musepack 插件</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="64"/>
        <source>Musepack Files</source>
        <translation>Musepack 文件</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="130"/>
        <source>About Musepack Audio Plugin</source>
        <translation>关于 Musepack 音频插件</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="131"/>
        <source>Qmmp Musepack Audio Plugin</source>
        <translation>Qmmp Musepack 音频插件</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="132"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>MPCMetaDataModel</name>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="46"/>
        <source>Length</source>
        <translation>长度</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Sample rate</source>
        <translation>取样率</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="48"/>
        <source>Channels</source>
        <translation>声音通道</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>Bitrate</source>
        <translation>比特率</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>KB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp-0.10.10.tar.bz2: qmmp-0.10.10/src/plugins/Input/mpc/translations/mpc_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>DecoderMPCFactory</name>
    <message>
        <location filename="../decodermpcfactory.cpp" line="62"/>
        <source>Musepack Plugin</source>
        <translation>Musepack 插件</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="64"/>
        <source>Musepack Files</source>
        <translation>Musepack 文件</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="133"/>
        <source>About Musepack Audio Plugin</source>
        <translation>关于 Musepack 音频插件</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="134"/>
        <source>Qmmp Musepack Audio Plugin</source>
        <translation>Qmmp Musepack 音频插件</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="135"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>MPCMetaDataModel</name>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="46"/>
        <source>Length</source>
        <translation>长度</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Sample rate</source>
        <translation>取样率</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Hz</source>
        <translation>赫兹</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="48"/>
        <source>Channels</source>
        <translation>声音通道</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>Bitrate</source>
        <translation>比特率</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>kbps</source>
        <translation>千比特每秒</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>KB</source>
        <translation>千字节</translation>
    </message>
</context>
</TS>
